using System;
using System.ComponentModel;
using System.Windows.Forms;

namespace ReflectionIT.DualList {
	/// <summary>
	/// Summary description for DualListComponent.
	/// </summary>
	public class DualListComponent : System.ComponentModel.Component {
		private Button _actionButton;
		private ListBox _source;
		private ListBox _destination;

		private bool _doubleClickSupport;
		private IButtonControl _acceptButton;

		[DefaultValue(false)]
		public bool DoubleClickSupport {
			get { return this._doubleClickSupport; }
			set {
				this._doubleClickSupport = value;
				if (value && Source != null) {
					Source.DoubleClick += new EventHandler(Source_DoubleClick);
					Source.Enter += new EventHandler(Source_Enter);
					Source.Leave += new EventHandler(Source_Leave);
				}
			}
		}

		private void Source_DoubleClick(object sender, EventArgs e) {
			ListBoxHelper.SwitchItem(Source, Destination);
		}

		private void Source_Enter(object sender, EventArgs e) {
			Form currentForm = Source.FindForm();
			_acceptButton = currentForm.AcceptButton;
			currentForm.AcceptButton = ActionButton;
		}

		private void Source_Leave(object sender, EventArgs e) {
			Source.FindForm().AcceptButton = _acceptButton;
		}

		public Button ActionButton {
			get { return this._actionButton; }
			set {
				this._actionButton = value;
				if (_actionButton != null) {
					_actionButton.Click += new EventHandler(ActionButton_Click);
				}
			}
		}

		public ListBox Source {
			get { return this._source; }
			set { 
				this._source = value;
				DoubleClickSupport = DoubleClickSupport;
			}
		}

		public ListBox Destination {
			get { return this._destination; }
			set { this._destination = value; }
		}

		private void ActionButton_Click(object sender, EventArgs e) {
			ListBoxHelper.SwitchItem(Source, Destination);
		}
	}
}
